@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2018 IBM Corporation and others.
+ * Copyright (c) 2003, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Danail Nachev -  ProSyst - bug 218625
@@ -70,13 +70,13 @@ public abstract class StateImpl implements State {
 	public static final String ECLIPSE_PLATFORMFILTER = "Eclipse-PlatformFilter"; //$NON-NLS-1$
 	public static final String Eclipse_JREBUNDLE = "Eclipse-JREBundle"; //$NON-NLS-1$
 	/**
-	 * Manifest Export-Package directive indicating that the exported package should only 
+	 * Manifest Export-Package directive indicating that the exported package should only
 	 * be made available when the resolver is not in strict mode.
 	 */
 	public static final String INTERNAL_DIRECTIVE = "x-internal"; //$NON-NLS-1$
 
 	/**
-	 * Manifest Export-Package directive indicating that the exported package should only 
+	 * Manifest Export-Package directive indicating that the exported package should only
 	 * be made available to friends of the exporting bundle.
 	 */
 	public static final String FRIENDS_DIRECTIVE = "x-friends"; //$NON-NLS-1$
@@ -94,6 +94,7 @@ public abstract class StateImpl implements State {
 	 * <tt>Dictionary</tt> object returned by the <tt>Bundle.getHeaders</tt> method.
 	 * @deprecated
 	 */
+	@Deprecated
 	public final static String PROVIDE_PACKAGE = "Provide-Package"; //$NON-NLS-1$
 
 	/**
@@ -103,7 +104,7 @@ public abstract class StateImpl implements State {
 	 * by the required bundle must be reprovided by the requiring bundle.
 	 * The default value is <tt>false</tt>.
 	 * <p>
-	 * The attribute value is encoded in the Require-Bundle manifest 
+	 * The attribute value is encoded in the Require-Bundle manifest
 	 * header like:
 	 * <pre>
 	 * Require-Bundle: com.acme.module.test; reprovide="true"
@@ -113,17 +114,18 @@ public abstract class StateImpl implements State {
 	 * syntax version 2 will not recognize this attribute.
 	 * @deprecated
 	 */
+	@Deprecated
 	public final static String REPROVIDE_ATTRIBUTE = "reprovide"; //$NON-NLS-1$
 
 	/**
 	 * Manifest header attribute (named &quot;optional&quot;)
 	 * for Require-Bundle
 	 * identifying that a required bundle is optional and that
-	 * the requiring bundle can be resolved if there is no 
+	 * the requiring bundle can be resolved if there is no
 	 * suitable required bundle.
 	 * The default value is <tt>false</tt>.
 	 *
-	 * <p>The attribute value is encoded in the Require-Bundle manifest 
+	 * <p>The attribute value is encoded in the Require-Bundle manifest
 	 * header like:
 	 * <pre>
 	 * Require-Bundle: com.acme.module.test; optional="true"
@@ -134,6 +136,7 @@ public abstract class StateImpl implements State {
 	 * @since 1.3 <b>EXPERIMENTAL</b>
 	 * @deprecated
 	 */
+	@Deprecated
 	public final static String OPTIONAL_ATTRIBUTE = "optional"; //$NON-NLS-1$
 
 	public static final String OSGI_RESOLVER_MODE = "osgi.resolverMode"; //$NON-NLS-1$
@@ -177,7 +180,7 @@ public abstract class StateImpl implements State {
 
 	final Object monitor = new Object();
 
-	// to prevent extra-package instantiation 
+	// to prevent extra-package instantiation
 	protected StateImpl() {
 		// always add the default platform property keys.
 		addPlatformPropertyKeys(PROPS);
@@ -420,6 +423,7 @@ public abstract class StateImpl implements State {
 	/**
 	 * @deprecated
 	 */
+	@Deprecated
 	public void resolveBundle(BundleDescription bundle, boolean status, BundleDescription[] hosts, ExportPackageDescription[] selectedExports, BundleDescription[] resolvedRequires, ExportPackageDescription[] resolvedImports) {
 		resolveBundle(bundle, status, hosts, selectedExports, null, resolvedRequires, resolvedImports);
 	}
@@ -427,6 +431,7 @@ public abstract class StateImpl implements State {
 	/**
 	 * @deprecated
 	 */
+	@Deprecated
 	public void resolveBundle(BundleDescription bundle, boolean status, BundleDescription[] hosts, ExportPackageDescription[] selectedExports, ExportPackageDescription[] substitutedExports, BundleDescription[] resolvedRequires, ExportPackageDescription[] resolvedImports) {
 		resolveBundle(bundle, status, hosts, selectedExports, substitutedExports, null, resolvedRequires, resolvedImports, null, null);
 	}
@@ -436,7 +441,7 @@ public abstract class StateImpl implements State {
 			if (!resolving)
 				throw new IllegalStateException(); // TODO need error message here!
 			BundleDescriptionImpl modifiable = (BundleDescriptionImpl) bundle;
-			// must record the change before setting the resolve state to 
+			// must record the change before setting the resolve state to
 			// accurately record if a change has happened.
 			getDelta().recordBundleResolved(modifiable, status);
 			// force the new resolution data to stay in memory; we will not read this from disk anymore
@@ -556,7 +561,7 @@ public abstract class StateImpl implements State {
 					if (resolved && reResolve == null)
 						return new StateDeltaImpl(this);
 					if (developmentMode) {
-						// in dev mode we need to aggressively flush removal pendings 
+						// in dev mode we need to aggressively flush removal pendings
 						if (removalPendings.size() > 0) {
 							BundleDescription[] removed = internalGetRemovalPending();
 							reResolve = mergeBundles(reResolve, removed);
@@ -588,8 +593,7 @@ public abstract class StateImpl implements State {
 
 				ResolverHookFactory currentFactory = hookFactory;
 				if (currentFactory != null) {
-					@SuppressWarnings("unchecked")
-					Collection<BundleRevision> triggerRevisions = Collections.unmodifiableCollection(triggers == null ? Collections.EMPTY_LIST : Arrays.asList((BundleRevision[]) triggers));
+					Collection<BundleRevision> triggerRevisions = Collections.unmodifiableCollection(triggers == null ? Collections.emptyList() : Arrays.asList((BundleRevision[]) triggers));
 					begin(triggerRevisions);
 				}
 				ResolverHookException error = null;
@@ -945,7 +949,7 @@ public abstract class StateImpl implements State {
 				addSystemExports(exports, ManifestElement.parseHeader(Constants.EXPORT_PACKAGE, (String) platformProperties[i].get(Constants.FRAMEWORK_SYSTEMPACKAGES)), i);
 				addSystemExports(exports, ManifestElement.parseHeader(Constants.EXPORT_PACKAGE, (String) platformProperties[i].get(Constants.FRAMEWORK_SYSTEMPACKAGES_EXTRA)), i);
 			} catch (BundleException e) {
-				// TODO consider throwing this... 
+				// TODO consider throwing this...
 			}
 	}
 
@@ -983,7 +987,7 @@ public abstract class StateImpl implements State {
 				addSystemCapabilities(capabilities, ManifestElement.parseHeader(Constants.PROVIDE_CAPABILITY, (String) platformProperties[i].get(Constants.FRAMEWORK_SYSTEMCAPABILITIES_EXTRA)), i);
 				checkOSGiEE(capabilities, (String) platformProperties[i].get(Constants.FRAMEWORK_EXECUTIONENVIRONMENT), i);
 			} catch (BundleException e) {
-				// TODO consider throwing this... 
+				// TODO consider throwing this...
 			}
 	}
 
@@ -1148,7 +1152,7 @@ public abstract class StateImpl implements State {
 				// ask the resolver to resolve our dynamic import
 				ExportPackageDescriptionImpl result = (ExportPackageDescriptionImpl) resolver.resolveDynamicImport(importingBundle, requestedPackage);
 				if (result == null)
-					importer.setDynamicStamp(requestedPackage, new Long(getTimeStamp()));
+					importer.setDynamicStamp(requestedPackage, Long.valueOf(getTimeStamp()));
 				else {
 					importer.setDynamicStamp(requestedPackage, null); // remove any cached timestamp
 					// need to add the result to the list of resolved imports
