@@ -14,10 +14,26 @@
 
 package org.eclipse.osgi.tests.debugoptions;
 
-import java.io.*;
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
+import java.io.FilterOutputStream;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.io.OutputStream;
+import java.io.PrintStream;
+import java.io.Reader;
+import java.nio.charset.StandardCharsets;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Dictionary;
+import java.util.HashMap;
+import java.util.Hashtable;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicReference;
 import junit.framework.Test;
@@ -25,7 +41,9 @@ import junit.framework.TestSuite;
 import org.eclipse.core.tests.harness.CoreTest;
 import org.eclipse.osgi.internal.debug.FrameworkDebugOptions;
 import org.eclipse.osgi.internal.debug.FrameworkDebugTraceEntry;
-import org.eclipse.osgi.service.debug.*;
+import org.eclipse.osgi.service.debug.DebugOptions;
+import org.eclipse.osgi.service.debug.DebugOptionsListener;
+import org.eclipse.osgi.service.debug.DebugTrace;
 import org.eclipse.osgi.tests.OSGiTestsActivator;
 import org.osgi.framework.ServiceReference;
 import org.osgi.framework.ServiceRegistration;
@@ -80,7 +98,7 @@ public class DebugOptionsTestCase extends CoreTest {
 	 * Test that a new {@link FrameworkDebugTraceEntry} object created without a trace class
 	 * has 'org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase' as the class name and
 	 * 'testTracingEntry01' as the method name that it determined as the caller of it.
-	 * 
+	 *
 	 * This test mimics the tracing framework to ensure that the correct class name and method name
 	 * are returned and written to the trace file.
 	 */
@@ -92,7 +110,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		FrameworkDebugTraceEntry traceEntry = new FrameworkDebugTraceEntry(bundleName, optionPath, message, null);
 		String correctClassName = "org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase"; //$NON-NLS-1$
 		String correctMethodName = "testTracingEntry01"; //$NON-NLS-1$
-		assertEquals("The class calling the trace API does not match the expected value.", correctClassName, traceEntry.getClassName()); //$NON-NLS-1$  
+		assertEquals("The class calling the trace API does not match the expected value.", correctClassName, traceEntry.getClassName()); //$NON-NLS-1$
 		assertEquals("The method calling the trace API does not match the expected value.", correctMethodName, traceEntry.getMethodName()); //$NON-NLS-1$
 	}
 
@@ -100,7 +118,7 @@ public class DebugOptionsTestCase extends CoreTest {
 	 * Test that a new {@link FrameworkDebugTraceEntry} object created with a trace class
 	 * of 'org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase' has the correct class name and
 	 * method name of the caller.
-	 * 
+	 *
 	 * This test mimics the tracing framework to ensure that the correct class name and method name
 	 * are returned and written to the trace file.
 	 */
@@ -109,7 +127,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		String correctClassName = Runner1.class.getName();
 		String correctMethodName = "run"; //$NON-NLS-1$
 		FrameworkDebugTraceEntry traceEntry = new Runner1().run();
-		assertEquals("The class calling the trace API does not match the expected value.", correctClassName, traceEntry.getClassName()); //$NON-NLS-1$  
+		assertEquals("The class calling the trace API does not match the expected value.", correctClassName, traceEntry.getClassName()); //$NON-NLS-1$
 		assertEquals("The method calling the trace API does not match the expected value.", correctMethodName, traceEntry.getMethodName()); //$NON-NLS-1$
 	}
 
@@ -211,7 +229,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		assertNull("Found bad value: " + listener.getIncorrectValue(), listener.getIncorrectValue()); //$NON-NLS-1$
 
 		listener.clear();
-		checkValues.put(getName() + "/debug", null); //$NON-NLS-1$ 
+		checkValues.put(getName() + "/debug", null); //$NON-NLS-1$
 		listener.setCheckValues(checkValues);
 		debugOptions.setDebugEnabled(false);
 		assertFalse("Debug is enabled", debugOptions.isDebugEnabled()); //$NON-NLS-1$
@@ -236,7 +254,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		String key1 = getName() + "/debug/disableCheck1";
 		String key2 = getName() + "/debug/disableCheck2";
 		String key3 = getName() + "/debug/disableCheck3";
-		Map /* <String, String> */newOptions = new HashMap();
+		Map /* <String, String> */ newOptions = new HashMap();
 		newOptions.put(key1, "ok1");
 		newOptions.put(key2, "ok2");
 		newOptions.put(key3, "ok3");
@@ -247,7 +265,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		// make sure the listener got called
 		assertTrue("Listener did not get called when setting batch options when tracing is enabled", listener.gotCalled()); //$NON-NLS-1$
 		// get all of the options
-		Map/* <String, String> */currentOptions = debugOptions.getOptions();
+		Map/* <String, String> */ currentOptions = debugOptions.getOptions();
 		// make sure the Map object returned is not the same Map object that was set
 		assertNotSame("The Map object set is the exact same Map object returned", newOptions, currentOptions);
 		// make sure the size is correct (it should be the same as the original Map)
@@ -263,7 +281,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		String key4 = getName() + "/debug/disableCheck4";
 		String key5 = getName() + "/debug/disableCheck5";
 		String key6 = getName() + "/debug/disableCheck6";
-		Map /* <String, String> */newOptions2 = new HashMap();
+		Map /* <String, String> */ newOptions2 = new HashMap();
 		newOptions2.put(key4, "ok4");
 		newOptions2.put(key5, "ok5");
 		newOptions2.put(key6, "ok6");
@@ -330,7 +348,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		String key1 = getName() + "/debug/disableCheck1";
 		String key2 = getName() + "/debug/disableCheck2";
 		String key3 = getName() + "/debug/disableCheck3";
-		Map /* <String, String> */newOptions = new HashMap();
+		Map /* <String, String> */ newOptions = new HashMap();
 		newOptions.put(key1, "ok1");
 		newOptions.put(key2, "ok2");
 		newOptions.put(key3, "ok3");
@@ -363,7 +381,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		String key4 = getName() + "/debug/disableCheck4";
 		String key5 = getName() + "/debug/disableCheck5";
 		String key6 = getName() + "/debug/disableCheck6";
-		Map /* <String, String> */newOptions2 = new HashMap();
+		Map /* <String, String> */ newOptions2 = new HashMap();
 		newOptions2.put(key4, "ok4");
 		newOptions2.put(key5, "ok5");
 		newOptions2.put(key6, "ok6");
@@ -542,7 +560,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		expectedThrowableText1.append(exceptionMessage1);
 		expectedThrowableText1.append(DebugOptionsTestCase.LINE_SEPARATOR);
 		expectedThrowableText1.append(DebugOptionsTestCase.TAB_CHARACTER);
-		expectedThrowableText1.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testVerboseDebugging(DebugOptionsTestCase.java:"); //$NON-NLS-1$		
+		expectedThrowableText1.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testVerboseDebugging(DebugOptionsTestCase.java:"); //$NON-NLS-1$
 		if (!traceOutput[0].getThrowableText().startsWith(expectedThrowableText1.toString())) {
 			final StringBuilder errorMessage = new StringBuilder("The expected throwable text does not start with the actual throwable text."); //$NON-NLS-1$
 			errorMessage.append(DebugOptionsTestCase.LINE_SEPARATOR);
@@ -641,7 +659,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		final String exceptionMessage2 = "An error 2"; //$NON-NLS-1$
 		final String exceptionMessage3 = "An error 3"; //$NON-NLS-1$
 		try {
-			debugTrace.trace("/debug", "testing 1", new Exception(exceptionMessage1)); //$NON-NLS-1$ //$NON-NLS-2$ 
+			debugTrace.trace("/debug", "testing 1", new Exception(exceptionMessage1)); //$NON-NLS-1$ //$NON-NLS-2$
 			debugTrace.trace("/notset", "testing 2", new Exception(exceptionMessage2)); //$NON-NLS-1$ //$NON-NLS-2$
 			debugTrace.trace("/debug", "testing 3", new Exception(exceptionMessage3)); //$NON-NLS-1$ //$NON-NLS-2$
 			traceOutput = readTraceFile(traceFile); // Note: this call will also delete the trace file
@@ -653,7 +671,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		expectedThrowableText1.append(exceptionMessage1);
 		expectedThrowableText1.append(DebugOptionsTestCase.LINE_SEPARATOR);
 		expectedThrowableText1.append(DebugOptionsTestCase.TAB_CHARACTER);
-		expectedThrowableText1.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testTraceFile02(DebugOptionsTestCase.java:"); //$NON-NLS-1$		
+		expectedThrowableText1.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testTraceFile02(DebugOptionsTestCase.java:"); //$NON-NLS-1$
 
 		assertEquals("Wrong number of trace entries", 2, traceOutput.length); //$NON-NLS-1$
 		assertEquals("Thread name is incorrect", Thread.currentThread().getName(), traceOutput[0].getThreadName()); //$NON-NLS-1$
@@ -688,7 +706,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		expectedThrowableText2.append(exceptionMessage3);
 		expectedThrowableText2.append(DebugOptionsTestCase.LINE_SEPARATOR);
 		expectedThrowableText2.append(DebugOptionsTestCase.TAB_CHARACTER);
-		expectedThrowableText2.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testTraceFile02(DebugOptionsTestCase.java:"); //$NON-NLS-1$		
+		expectedThrowableText2.append("at org.eclipse.osgi.tests.debugoptions.DebugOptionsTestCase.testTraceFile02(DebugOptionsTestCase.java:"); //$NON-NLS-1$
 
 		assertEquals("Thread name is incorrect", Thread.currentThread().getName(), traceOutput[1].getThreadName()); //$NON-NLS-1$
 		assertEquals("Bundle name is incorrect", getName(), traceOutput[1].getBundleSymbolicName()); //$NON-NLS-1$
@@ -969,7 +987,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		PrintStream old = System.out;
 		File traceFile = OSGiTestsActivator.getContext().getDataFile(getName() + ".trace"); //$NON-NLS-1$
 		OutputStream out = new FileOutputStream(traceFile);
-		final AtomicReference<Boolean> closed = new AtomicReference<Boolean>(Boolean.FALSE);
+		final AtomicReference<Boolean> closed = new AtomicReference<>(Boolean.FALSE);
 		out = new FilterOutputStream(out) {
 
 			@Override
@@ -1027,7 +1045,7 @@ public class DebugOptionsTestCase extends CoreTest {
 		List traceEntries = new ArrayList();
 		this.verboseDebug = true; // default is true
 		try {
-			traceReader = new BufferedReader(new InputStreamReader(new FileInputStream(traceFile), "UTF-8")); //$NON-NLS-1$
+			traceReader = new BufferedReader(new InputStreamReader(new FileInputStream(traceFile), StandardCharsets.UTF_8));
 			TraceEntry entry = null;
 			while ((entry = this.readMessage(traceReader)) != null) {
 				traceEntries.add(entry);
@@ -1161,7 +1179,7 @@ public class DebugOptionsTestCase extends CoreTest {
 
 		/**
 		 * The date and time when the trace occurred.
-		 * 
+		 *
 		 */
 		private final long timestamp;
 
