@@ -13,16 +13,11 @@
  *******************************************************************************/
 package org.eclipse.osgi.tests.filter;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
 import org.eclipse.osgi.tests.OSGiTestsActivator;
 import org.osgi.framework.Filter;
 import org.osgi.framework.InvalidSyntaxException;
 
 public class BundleContextFilterTests extends FilterTests {
-	public static Test suite() {
-		return new TestSuite(BundleContextFilterTests.class);
-	}
 
 	@Override
 	public Filter createFilter(String filterString) throws InvalidSyntaxException {
