@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2018 IBM Corporation and others.
+ * Copyright (c) 2012, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,12 +7,13 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.osgi.container;
 
+import java.io.Closeable;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
@@ -25,12 +26,19 @@ import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.Executor;
+import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.concurrent.locks.ReentrantLock;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 import org.eclipse.osgi.container.Module.StartOptions;
 import org.eclipse.osgi.container.Module.State;
 import org.eclipse.osgi.container.Module.StopOptions;
+import org.eclipse.osgi.container.ModuleContainer.ResolutionLock.Permits;
 import org.eclipse.osgi.container.ModuleContainerAdaptor.ContainerEvent;
 import org.eclipse.osgi.container.ModuleContainerAdaptor.ModuleEvent;
 import org.eclipse.osgi.container.ModuleDatabase.Sort;
@@ -40,6 +48,7 @@ import org.eclipse.osgi.framework.eventmgr.EventDispatcher;
 import org.eclipse.osgi.framework.eventmgr.EventManager;
 import org.eclipse.osgi.framework.eventmgr.ListenerQueue;
 import org.eclipse.osgi.framework.util.SecureAction;
+import org.eclipse.osgi.framework.util.ThreadInfoReport;
 import org.eclipse.osgi.internal.container.InternalUtils;
 import org.eclipse.osgi.internal.container.LockSet;
 import org.eclipse.osgi.internal.debug.Debug;
@@ -108,7 +117,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 	final ModuleContainerAdaptor adaptor;
 
 	/**
-	 * The module resolver which implements the ResolverContext and handles calling the 
+	 * The module resolver which implements the ResolverContext and handles calling the
 	 * resolver service.
 	 */
 	private final ModuleResolver moduleResolver;
@@ -122,7 +131,10 @@ public final class ModuleContainer implements DebugOptionsListener {
 
 	private final boolean autoStartOnResolve;
 
+	final boolean restrictParallelStart;
+
 	boolean DEBUG_MONITOR_LAZY = false;
+	boolean DEBUG_BUNDLE_START_TIME = false;
 
 	/**
 	 * Constructs a new container with the specified adaptor, module database.
@@ -135,7 +147,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 		this.moduleDatabase = moduledataBase;
 		this.frameworkWiring = new ContainerWiring();
 		this.frameworkStartLevel = new ContainerStartLevel();
-		long tempModuleLockTimeout = 5;
+		long tempModuleLockTimeout = 30;
 		String moduleLockTimeoutProp = adaptor.getProperty(EquinoxConfiguration.PROP_MODULE_LOCK_TIMEOUT);
 		if (moduleLockTimeoutProp != null) {
 			try {
@@ -145,7 +157,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 					tempModuleLockTimeout = 1;
 				}
 			} catch (NumberFormatException e) {
-				// will default to 5
+				// will default to 30
 			}
 		}
 		this.moduleLockTimeout = tempModuleLockTimeout;
@@ -159,6 +171,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 			autoStartOnResolveProp = Boolean.toString(true);
 		}
 		this.autoStartOnResolve = Boolean.parseBoolean(autoStartOnResolveProp);
+		this.restrictParallelStart = Boolean.parseBoolean(adaptor.getProperty(EquinoxConfiguration.PROP_EQUINOX_START_LEVEL_RESTRICT_PARALLEL));
 	}
 
 	/**
@@ -178,7 +191,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 	}
 
 	/**
-	 * Returns the module installed with the specified id, or null if no 
+	 * Returns the module installed with the specified id, or null if no
 	 * such module is installed.
 	 * @param id the id of the module
 	 * @return the module with the specified id, or null of no such module is installed.
@@ -188,7 +201,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 	}
 
 	/**
-	 * Returns the module installed with the specified location, or null if no 
+	 * Returns the module installed with the specified location, or null if no
 	 * such module is installed.
 	 * @param location the location of the module
 	 * @return the module with the specified location, or null of no such module is installed.
@@ -201,7 +214,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 	 * Creates a synthetic requirement that is not associated with any module revision.
 	 * This is useful for calling {@link FrameworkWiring#findProviders(Requirement)}.
 	 * @param namespace the requirement namespace
-	 * @param directives the requriement directives
+	 * @param directives the requirement directives
 	 * @param attributes the requirement attributes
 	 * @return a synthetic requirement
 	 */
@@ -211,17 +224,17 @@ public final class ModuleContainer implements DebugOptionsListener {
 
 	/**
 	 * Installs a new module using the specified location.  The specified
-	 * builder is used to create a new {@link ModuleRevision revision} 
+	 * builder is used to create a new {@link ModuleRevision revision}
 	 * which will become the {@link Module#getCurrentRevision() current}
 	 * revision of the new module.
 	 * <p>
-	 * If a module already exists with the specified location then the 
+	 * If a module already exists with the specified location then the
 	 * existing module is returned and the builder is not used.
 	 * @param origin the module performing the install, may be {@code null}.
-	 * @param location The location identifier of the module to install. 
+	 * @param location The location identifier of the module to install.
 	 * @param builder the builder used to create the revision to install.
 	 * @param revisionInfo the revision info for the new revision, may be {@code null}.
-	 * @return a new module or a existing module if one exists at the 
+	 * @return a new module or a existing module if one exists at the
 	 *     specified location.
 	 * @throws BundleException if some error occurs installing the module
 	 */
@@ -242,10 +255,10 @@ public final class ModuleContainer implements DebugOptionsListener {
 				locationLocked = locationLocks.tryLock(location, 5, TimeUnit.SECONDS);
 				nameLocked = name != null && nameLocks.tryLock(name, 5, TimeUnit.SECONDS);
 				if (!locationLocked) {
-					throw new BundleException("Failed to obtain location lock for installation: " + location, BundleException.STATECHANGE_ERROR); //$NON-NLS-1$
+					throw new BundleException("Failed to obtain location lock for installation: " + location, BundleException.STATECHANGE_ERROR, new ThreadInfoReport(locationLocks.getLockInfo(location))); //$NON-NLS-1$
 				}
 				if (name != null && !nameLocked) {
-					throw new BundleException("Failed to obtain symbolic name lock for installation: " + name, BundleException.STATECHANGE_ERROR); //$NON-NLS-1$
+					throw new BundleException("Failed to obtain symbolic name lock for installation: " + name, BundleException.STATECHANGE_ERROR, new ThreadInfoReport(nameLocks.getLockInfo(name))); //$NON-NLS-1$
 				}
 			} catch (InterruptedException e) {
 				Thread.currentThread().interrupt();
@@ -312,7 +325,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 
 	/**
 	 * Updates the specified module with a new revision.  The specified
-	 * builder is used to create a new {@link ModuleRevision revision} 
+	 * builder is used to create a new {@link ModuleRevision revision}
 	 * which will become the {@link Module#getCurrentRevision() current}
 	 * revision of the new module.
 	 * @param module the module to update
@@ -335,7 +348,8 @@ public final class ModuleContainer implements DebugOptionsListener {
 			// Attempt to lock the name
 			try {
 				if (name != null && !(nameLocked = nameLocks.tryLock(name, 5, TimeUnit.SECONDS))) {
-					throw new BundleException("Failed to obtain id locks for installation.", BundleException.STATECHANGE_ERROR); //$NON-NLS-1$
+					throw new BundleException("Failed to obtain id locks for installation: " + name, //$NON-NLS-1$
+							BundleException.STATECHANGE_ERROR, new ThreadInfoReport(nameLocks.getLockInfo(name)));
 				}
 			} catch (InterruptedException e) {
 				Thread.currentThread().interrupt();
@@ -468,7 +482,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 	 * Attempts to resolve the current revisions of the specified modules.
 	 * @param triggers the modules to resolve or {@code null} to resolve all unresolved
 	 *    current revisions.
-	 * @param triggersMandatory true if the triggers must be resolved.  This will result in 
+	 * @param triggersMandatory true if the triggers must be resolved.  This will result in
 	 *   a {@link ResolutionException} if set to true and one of the triggers could not be resolved.
 	 * @see FrameworkWiring#resolveBundles(Collection)
 	 * @return A resolution report for the resolve operation
@@ -482,23 +496,27 @@ public final class ModuleContainer implements DebugOptionsListener {
 			return new ModuleResolutionReport(null, Collections.<Resource, List<Entry>> emptyMap(), new ResolutionException("Unable to resolve while shutting down the framework.")); //$NON-NLS-1$
 		}
 		ResolutionReport report = null;
-		do {
-			try {
-				report = resolveAndApply(triggers, triggersMandatory, restartTriggers);
-			} catch (RuntimeException e) {
-				if (e.getCause() instanceof BundleException) {
-					BundleException be = (BundleException) e.getCause();
-					if (be.getType() == BundleException.REJECTED_BY_HOOK || be.getType() == BundleException.STATECHANGE_ERROR) {
-						return new ModuleResolutionReport(null, Collections.<Resource, List<Entry>> emptyMap(), new ResolutionException(be));
+		try (ResolutionLock.Permits resolutionPermits = _resolutionLock.acquire(1)) {
+			do {
+				try {
+					report = resolveAndApply(triggers, triggersMandatory, restartTriggers, resolutionPermits);
+				} catch (RuntimeException e) {
+					if (e.getCause() instanceof BundleException) {
+						BundleException be = (BundleException) e.getCause();
+						if (be.getType() == BundleException.REJECTED_BY_HOOK || be.getType() == BundleException.STATECHANGE_ERROR) {
+							return new ModuleResolutionReport(null, Collections.<Resource, List<Entry>> emptyMap(), new ResolutionException(be));
+						}
 					}
+					throw e;
 				}
-				throw e;
-			}
-		} while (report == null);
+			} while (report == null);
+		} catch (ResolutionLockException e) {
+			return new ModuleResolutionReport(null, Collections.<Resource, List<Entry>> emptyMap(), new ResolutionException("Timeout acquiring lock for resolution", e, Collections.<Requirement> emptyList())); //$NON-NLS-1$
+		}
 		return report;
 	}
 
-	private ResolutionReport resolveAndApply(Collection<Module> triggers, boolean triggersMandatory, boolean restartTriggers) {
+	private ResolutionReport resolveAndApply(Collection<Module> triggers, boolean triggersMandatory, boolean restartTriggers, ResolutionLock.Permits resolutionPermits) {
 		if (triggers == null)
 			triggers = new ArrayList<>(0);
 		Collection<ModuleRevision> triggerRevisions = new ArrayList<>(triggers.size());
@@ -538,14 +556,14 @@ public final class ModuleContainer implements DebugOptionsListener {
 				modulesResolved.add(deltaRevision.getRevisions().getModule());
 		}
 
-		return applyDelta(deltaWiring, modulesResolved, triggers, timestamp, restartTriggers) ? report : null;
+		return applyDelta(deltaWiring, modulesResolved, triggers, timestamp, restartTriggers, resolutionPermits) ? report : null;
 	}
 
 	/**
 	 * Attempts to resolve the specified dynamic package name request for the specified revision.
 	 * @param dynamicPkgName the package name to attempt a dynamic resolution for
 	 * @param revision the module revision the dynamic resolution request is for
-	 * @return the new resolution wire establishing a dynamic package resolution or null if 
+	 * @return the new resolution wire establishing a dynamic package resolution or null if
 	 * a dynamic wire could not be established.
 	 */
 	public ModuleWire resolveDynamic(String dynamicPkgName, ModuleRevision revision) {
@@ -553,90 +571,94 @@ public final class ModuleContainer implements DebugOptionsListener {
 		Map<ModuleRevision, ModuleWiring> deltaWiring;
 		Collection<Module> modulesResolved;
 		long timestamp;
-		do {
-			result = null;
-			Map<ModuleRevision, ModuleWiring> wiringClone = null;
-			List<DynamicModuleRequirement> dynamicReqs = null;
-			Collection<ModuleRevision> unresolved = new ArrayList<>();
-			moduleDatabase.readLock();
-			try {
-				ModuleWiring wiring = revision.getWiring();
-				if (wiring == null) {
-					// not resolved!!
-					return null;
-				}
-				if (wiring.isDynamicPackageMiss(dynamicPkgName)) {
-					// cached a miss for this package
-					return null;
-				}
-				// need to check that another thread has not done the work already
-				result = findExistingDynamicWire(revision.getWiring(), dynamicPkgName);
-				if (result != null) {
-					return result;
-				}
-				dynamicReqs = getDynamicRequirements(dynamicPkgName, revision);
-				if (dynamicReqs.isEmpty()) {
-					// save the miss for the package name
-					wiring.addDynamicPackageMiss(dynamicPkgName);
-					return null;
-				}
-				timestamp = moduleDatabase.getRevisionsTimestamp();
-				wiringClone = moduleDatabase.getWiringsClone();
-				Collection<Module> allModules = moduleDatabase.getModules();
-				for (Module module : allModules) {
-					ModuleRevision current = module.getCurrentRevision();
-					if (current != null && !wiringClone.containsKey(current))
-						unresolved.add(current);
-				}
-			} finally {
-				moduleDatabase.readUnlock();
-			}
-
-			deltaWiring = null;
-			boolean foundCandidates = false;
-			for (DynamicModuleRequirement dynamicReq : dynamicReqs) {
-				ModuleResolutionReport report = moduleResolver.resolveDynamicDelta(dynamicReq, unresolved, wiringClone, moduleDatabase);
-				Map<Resource, List<Wire>> resolutionResult = report.getResolutionResult();
-				deltaWiring = resolutionResult == null ? Collections.<ModuleRevision, ModuleWiring> emptyMap() : moduleResolver.generateDelta(resolutionResult, wiringClone);
-				if (deltaWiring.get(revision) != null) {
-					break;
-				}
-				// Did not establish a valid wire.
-				// Check to see if any candidates were available.
-				// this is used for caching purposes below
-				List<Entry> revisionEntries = report.getEntries().get(revision);
-				if (revisionEntries == null || revisionEntries.isEmpty()) {
-					foundCandidates = true;
-				} else {
-					// must make sure there is no MISSING_CAPABILITY type entry
-					boolean isMissingCapability = false;
-					for (Entry entry : revisionEntries) {
-						isMissingCapability |= Entry.Type.MISSING_CAPABILITY.equals(entry.getType());
-					}
-					foundCandidates |= !isMissingCapability;
-				}
-			}
-			if (deltaWiring == null || deltaWiring.get(revision) == null) {
-				if (!foundCandidates) {
+		try (Permits resolutionPermits = _resolutionLock.acquire(ResolutionLock.MAX_RESOLUTION_PERMITS)) {
+			do {
+				result = null;
+				Map<ModuleRevision, ModuleWiring> wiringClone = null;
+				List<DynamicModuleRequirement> dynamicReqs = null;
+				Collection<ModuleRevision> unresolved = new ArrayList<>();
+				moduleDatabase.readLock();
+				try {
 					ModuleWiring wiring = revision.getWiring();
-					if (wiring != null) {
+					if (wiring == null) {
+						// not resolved!!
+						return null;
+					}
+					if (wiring.isDynamicPackageMiss(dynamicPkgName)) {
+						// cached a miss for this package
+						return null;
+					}
+					// need to check that another thread has not done the work already
+					result = findExistingDynamicWire(revision.getWiring(), dynamicPkgName);
+					if (result != null) {
+						return result;
+					}
+					dynamicReqs = getDynamicRequirements(dynamicPkgName, revision);
+					if (dynamicReqs.isEmpty()) {
 						// save the miss for the package name
 						wiring.addDynamicPackageMiss(dynamicPkgName);
+						return null;
+					}
+					timestamp = moduleDatabase.getRevisionsTimestamp();
+					wiringClone = moduleDatabase.getWiringsClone();
+					Collection<Module> allModules = moduleDatabase.getModules();
+					for (Module module : allModules) {
+						ModuleRevision current = module.getCurrentRevision();
+						if (current != null && !wiringClone.containsKey(current))
+							unresolved.add(current);
+					}
+				} finally {
+					moduleDatabase.readUnlock();
+				}
+
+				deltaWiring = null;
+				boolean foundCandidates = false;
+				for (DynamicModuleRequirement dynamicReq : dynamicReqs) {
+					ModuleResolutionReport report = moduleResolver.resolveDynamicDelta(dynamicReq, unresolved, wiringClone, moduleDatabase);
+					Map<Resource, List<Wire>> resolutionResult = report.getResolutionResult();
+					deltaWiring = resolutionResult == null ? Collections.<ModuleRevision, ModuleWiring> emptyMap() : moduleResolver.generateDelta(resolutionResult, wiringClone);
+					if (deltaWiring.get(revision) != null) {
+						break;
+					}
+					// Did not establish a valid wire.
+					// Check to see if any candidates were available.
+					// this is used for caching purposes below
+					List<Entry> revisionEntries = report.getEntries().get(revision);
+					if (revisionEntries == null || revisionEntries.isEmpty()) {
+						foundCandidates = true;
+					} else {
+						// must make sure there is no MISSING_CAPABILITY type entry
+						boolean isMissingCapability = false;
+						for (Entry entry : revisionEntries) {
+							isMissingCapability |= Entry.Type.MISSING_CAPABILITY.equals(entry.getType());
+						}
+						foundCandidates |= !isMissingCapability;
 					}
 				}
-				return null; // nothing to do
-			}
+				if (deltaWiring == null || deltaWiring.get(revision) == null) {
+					if (!foundCandidates) {
+						ModuleWiring wiring = revision.getWiring();
+						if (wiring != null) {
+							// save the miss for the package name
+							wiring.addDynamicPackageMiss(dynamicPkgName);
+						}
+					}
+					return null; // nothing to do
+				}
 
-			modulesResolved = new ArrayList<>();
-			for (ModuleRevision deltaRevision : deltaWiring.keySet()) {
-				if (!wiringClone.containsKey(deltaRevision))
-					modulesResolved.add(deltaRevision.getRevisions().getModule());
-			}
+				modulesResolved = new ArrayList<>();
+				for (ModuleRevision deltaRevision : deltaWiring.keySet()) {
+					if (!wiringClone.containsKey(deltaRevision))
+						modulesResolved.add(deltaRevision.getRevisions().getModule());
+				}
 
-			// Save the result
-			ModuleWiring wiring = deltaWiring.get(revision);
-			result = findExistingDynamicWire(wiring, dynamicPkgName);
-		} while (!applyDelta(deltaWiring, modulesResolved, Collections.<Module> emptyList(), timestamp, false));
+				// Save the result
+				ModuleWiring wiring = deltaWiring.get(revision);
+				result = findExistingDynamicWire(wiring, dynamicPkgName);
+			} while (!applyDelta(deltaWiring, modulesResolved, Collections.<Module> emptyList(), timestamp, false, resolutionPermits));
+		} catch (ResolutionLockException e) {
+			return null;
+		}
 
 		return result;
 	}
@@ -660,19 +682,97 @@ public final class ModuleContainer implements DebugOptionsListener {
 		return null;
 	}
 
-	private final Object stateLockMonitor = new Object();
+	// The resolution algorithm uses optimistic locking approach;
+	// This involves taking a snapshot of the state and performing an
+	// operation on the snapshot while holding no locks and then
+	// obtaining the write lock to apply the results.  If we
+	// detect the state has changed since the snapshot taken then
+	// the process is started over.  If we allow too many threads
+	// to try to do this at the same time it causes thrashing
+	// between taking the snapshot and successfully applying the
+	// results.  Instead of resorting to single threaded operations
+	// we choose to limit the number of concurrent resolves
+	final ResolutionLock _resolutionLock = new ResolutionLock();
+	final ReentrantLock _bundleStateLock = new ReentrantLock();
 
-	private boolean applyDelta(Map<ModuleRevision, ModuleWiring> deltaWiring, Collection<Module> modulesResolved, Collection<Module> triggers, long timestamp, boolean restartTriggers) {
+	static class ResolutionLockException extends Exception {
+		private static final long serialVersionUID = 1L;
+
+		public ResolutionLockException() {
+			super();
+		}
+
+		public ResolutionLockException(Throwable cause) {
+			super(cause);
+		}
+	}
+
+	/**
+	 * A resolution hook allows for a max of 10 threads to do resolution operations
+	 * at the same time.  The implementation uses a semaphore to grant the max number
+	 * of permits (threads) but a reentrant read lock is also used to detect reentry.
+	 * If a thread reenters then no extra permits are required by the thread.
+	 * This lock returns a Permits object that implements closeable for use in
+	 * try->with.  If permits is closed multiple times then the additional close
+	 * operations are a no-op.
+	 */
+	static class ResolutionLock {
+		final static int MAX_RESOLUTION_PERMITS = 10;
+		final Semaphore permitPool = new Semaphore(MAX_RESOLUTION_PERMITS);
+		final ReentrantReadWriteLock reenterLock = new ReentrantReadWriteLock();
+
+		class Permits implements Closeable {
+			private final int aquiredPermits;
+			private final AtomicBoolean closed = new AtomicBoolean();
+
+			Permits(int requestedPermits) throws ResolutionLockException {
+				if (reenterLock.getReadHoldCount() > 0) {
+					// thread is already holding permits; don't request more
+					requestedPermits = 0;
+				}
+				this.aquiredPermits = requestedPermits;
+				boolean previousInterruption = Thread.interrupted();
+				try {
+					if (!permitPool.tryAcquire(requestedPermits, 30, TimeUnit.SECONDS)) {
+						throw new ResolutionLockException();
+					}
+				} catch (InterruptedException e) {
+					throw new ResolutionLockException(e);
+				} finally {
+					if (previousInterruption) {
+						Thread.currentThread().interrupt();
+					}
+				}
+				// mark this thread as holding permits
+				reenterLock.readLock().lock();
+			}
+
+			@Override
+			public void close() {
+				if (closed.compareAndSet(false, true)) {
+					permitPool.release(aquiredPermits);
+					reenterLock.readLock().unlock();
+				}
+			}
+		}
+
+		Permits acquire(int requestedPermits) throws ResolutionLockException {
+			return new Permits(requestedPermits);
+		}
+	}
+
+	private boolean applyDelta(Map<ModuleRevision, ModuleWiring> deltaWiring, Collection<Module> modulesResolved, Collection<Module> triggers, long timestamp, boolean restartTriggers, ResolutionLock.Permits resolutionPermits) {
 		List<Module> modulesLocked = new ArrayList<>(modulesResolved.size());
 		// now attempt to apply the delta
 		try {
-			synchronized (stateLockMonitor) {
-				// Acquire the necessary RESOLVED state change lock.
-				// Note this is done while holding a global lock to avoid multiple threads trying to compete over
-				// locking multiple modules; otherwise out of order locks between modules can happen
-				// NOTE this MUST be done outside of holding the moduleDatabase lock also to avoid
-				// introducing out of order locks between the bundle state change lock and the moduleDatabase
-				// lock.
+			// Acquire the necessary RESOLVED state change lock.
+			// Note this is done while holding a global lock to avoid multiple threads trying to compete over
+			// locking multiple modules; otherwise out of order locks between modules can happen
+			// NOTE this MUST be done outside of holding the moduleDatabase lock also to avoid
+			// introducing out of order locks between the bundle state change lock and the moduleDatabase
+			// lock.
+			_bundleStateLock.lock();
+			try {
 				for (Module module : modulesResolved) {
 					try {
 						// avoid grabbing the lock if the timestamp has changed
@@ -690,7 +790,10 @@ public final class ModuleContainer implements DebugOptionsListener {
 						throw new IllegalStateException(Msg.ModuleContainer_StateLockError, e);
 					}
 				}
+			} finally {
+				_bundleStateLock.unlock();
 			}
+
 			Map<ModuleWiring, Collection<ModuleRevision>> hostsWithDynamicFrags = new HashMap<>(0);
 			moduleDatabase.writeLock();
 			try {
@@ -745,6 +848,9 @@ public final class ModuleContainer implements DebugOptionsListener {
 			}
 		}
 
+		// release resolution permits before firing events
+		resolutionPermits.close();
+
 		for (Module module : modulesLocked) {
 			adaptor.publishModuleEvent(ModuleEvent.RESOLVED, module, module);
 		}
@@ -895,18 +1001,19 @@ public final class ModuleContainer implements DebugOptionsListener {
 			// NOTE this MUST be done outside of holding the moduleDatabase lock also to avoid
 			// introducing out of order locks between the bundle state change lock and the moduleDatabase
 			// lock.
-			synchronized (stateLockMonitor) {
-				try {
-					// go in reverse order
-					for (ListIterator<Module> iTriggers = refreshTriggers.listIterator(refreshTriggers.size()); iTriggers.hasPrevious();) {
-						Module refreshModule = iTriggers.previous();
-						refreshModule.lockStateChange(ModuleEvent.UNRESOLVED);
-						modulesLocked.add(refreshModule);
-					}
-				} catch (BundleException e) {
-					// TODO throw some appropriate exception
-					throw new IllegalStateException(Msg.ModuleContainer_StateLockError, e);
+			_bundleStateLock.lock();
+			try {
+				// go in reverse order
+				for (ListIterator<Module> iTriggers = refreshTriggers.listIterator(refreshTriggers.size()); iTriggers.hasPrevious();) {
+					Module refreshModule = iTriggers.previous();
+					refreshModule.lockStateChange(ModuleEvent.UNRESOLVED);
+					modulesLocked.add(refreshModule);
 				}
+			} catch (BundleException e) {
+				// TODO throw some appropriate exception
+				throw new IllegalStateException(Msg.ModuleContainer_StateLockError, e);
+			} finally {
+				_bundleStateLock.unlock();
 			}
 			// Must not hold the module database lock while stopping bundles
 			// Stop any active bundles and remove non-active modules from the refreshTriggers
@@ -974,7 +1081,6 @@ public final class ModuleContainer implements DebugOptionsListener {
 				module.unlockStateChange(ModuleEvent.UNRESOLVED);
 			}
 		}
-
 		// publish unresolved events after giving up all locks
 		for (Module module : modulesUnresolved) {
 			adaptor.publishModuleEvent(ModuleEvent.UNRESOLVED, module, module);
@@ -986,7 +1092,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 		if (initial == null) {
 			return;
 		}
-		Long zero = new Long(0);
+		Long zero = Long.valueOf(0);
 		for (Iterator<Module> iModules = initial.iterator(); iModules.hasNext();) {
 			Module m = iModules.next();
 			if (m.getId().equals(zero)) {
@@ -1036,8 +1142,8 @@ public final class ModuleContainer implements DebugOptionsListener {
 	/**
 	 * Returns the dependency closure of for the specified modules.
 	 * @param initial The initial modules for which to generate the dependency closure
-	 * @return A collection containing a snapshot of the dependency closure of the specified 
-	 *    modules, or an empty collection if there were no specified modules. 
+	 * @return A collection containing a snapshot of the dependency closure of the specified
+	 *    modules, or an empty collection if there were no specified modules.
 	 */
 	public Collection<Module> getDependencyClosure(Collection<Module> initial) {
 		moduleDatabase.readLock();
@@ -1059,11 +1165,11 @@ public final class ModuleContainer implements DebugOptionsListener {
 
 	/**
 	 * Return the active start level value of this container.
-	 * 
+	 *
 	 * If the container is in the process of changing the start level this
 	 * method must return the active start level if this differs from the
 	 * requested start level.
-	 * 
+	 *
 	 * @return The active start level value of the Framework.
 	 */
 	public int getStartLevel() {
@@ -1398,7 +1504,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 					for (Bundle bundle : bundles) {
 						Module module = bundle.adapt(Module.class);
 						if (module == null)
-							throw new IllegalStateException("Could not adapt a bundle to a module."); //$NON-NLS-1$
+							throw new IllegalStateException("Could not adapt a bundle to a module. " + bundle); //$NON-NLS-1$
 						result.add(module);
 					}
 					return result;
@@ -1453,6 +1559,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 		frameworkStartLevel.setDebugOptions();
 		if (options != null) {
 			this.DEBUG_MONITOR_LAZY = options.getBooleanOption(Debug.OPTION_MONITOR_LAZY, false);
+			this.DEBUG_BUNDLE_START_TIME = options.getBooleanOption(Debug.OPTION_DEBUG_BUNDLE_START_TIME, false);
 		}
 	}
 
@@ -1464,7 +1571,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 		private final Object eventManagerLock = new Object();
 		private EventManager startLevelThread = null;
 		private final Object frameworkStartLevelLock = new Object();
-		private boolean debugStartLevel = false;
+		boolean debugStartLevel = false;
 		{
 			setDebugOptions();
 		}
@@ -1609,6 +1716,10 @@ public final class ModuleContainer implements DebugOptionsListener {
 					List<Module> sorted = null;
 					long currentTimestamp = Long.MIN_VALUE;
 					if (newStartLevel > currentSL) {
+						List<Module> lazyStart = null;
+						List<Module> lazyStartParallel = null;
+						List<Module> eagerStart = null;
+						List<Module> eagerStartParallel = null;
 						for (int i = currentSL; i < newStartLevel; i++) {
 							int toStartLevel = i + 1;
 							activeStartLevel.set(toStartLevel);
@@ -1619,12 +1730,17 @@ public final class ModuleContainer implements DebugOptionsListener {
 								moduleDatabase.readLock();
 								try {
 									sorted = moduleDatabase.getSortedModules(Sort.BY_START_LEVEL);
+									lazyStart = new ArrayList<>(sorted.size());
+									lazyStartParallel = new ArrayList<>(sorted.size());
+									eagerStart = new ArrayList<>(sorted.size());
+									eagerStartParallel = new ArrayList<>(sorted.size());
+									separateModulesByActivationPolicy(sorted, lazyStart, lazyStartParallel, eagerStart, eagerStartParallel);
 									currentTimestamp = moduleDatabase.getTimestamp();
 								} finally {
 									moduleDatabase.readUnlock();
 								}
 							}
-							incStartLevel(toStartLevel, sorted);
+							incStartLevel(toStartLevel, lazyStart, lazyStartParallel, eagerStart, eagerStartParallel);
 						}
 					} else {
 						for (int i = currentSL; i > newStartLevel; i--) {
@@ -1650,23 +1766,46 @@ public final class ModuleContainer implements DebugOptionsListener {
 						// of launching or shutting down the framework
 						adaptor.publishContainerEvent(ContainerEvent.START_LEVEL, module, null, listeners);
 					}
-				} catch (Error e) {
-					adaptor.publishContainerEvent(ContainerEvent.ERROR, module, e, listeners);
-					throw e;
-				} catch (RuntimeException e) {
+				} catch (Error | RuntimeException e) {
 					adaptor.publishContainerEvent(ContainerEvent.ERROR, module, e, listeners);
 					throw e;
 				}
 			}
 		}
 
-		private void incStartLevel(int toStartLevel, List<Module> sortedModules) {
-			incStartLevel(toStartLevel, sortedModules, true);
-			incStartLevel(toStartLevel, sortedModules, false);
+		private void incStartLevel(int toStartLevel, List<Module> lazyStart, List<Module> lazyStartParallel, List<Module> eagerStart, List<Module> eagerStartParallel) {
+			// start lazy activated first
+			// start parallel bundles first
+			incStartLevel(toStartLevel, lazyStartParallel, true);
+			incStartLevel(toStartLevel, lazyStart, false);
+			incStartLevel(toStartLevel, eagerStartParallel, true);
+			incStartLevel(toStartLevel, eagerStart, false);
 		}
 
-		private void incStartLevel(int toStartLevel, List<Module> sortedModules, boolean lazyOnly) {
+		private void separateModulesByActivationPolicy(List<Module> sortedModules, List<Module> lazyStart, List<Module> lazyStartParallel, List<Module> eagerStart, List<Module> eagerStartParallel) {
 			for (Module module : sortedModules) {
+				if (!restrictParallelStart || module.isParallelActivated()) {
+					if (module.isLazyActivate()) {
+						lazyStartParallel.add(module);
+					} else {
+						eagerStartParallel.add(module);
+					}
+				} else {
+					if (module.isLazyActivate()) {
+						lazyStart.add(module);
+					} else {
+						eagerStart.add(module);
+					}
+				}
+			}
+		}
+
+		private void incStartLevel(final int toStartLevel, List<Module> candidatesToStart, boolean inParallel) {
+			if (candidatesToStart.isEmpty()) {
+				return;
+			}
+			final List<Module> toStart = new ArrayList<>();
+			for (final Module module : candidatesToStart) {
 				if (isRefreshingSystemModule()) {
 					return;
 				}
@@ -1676,22 +1815,8 @@ public final class ModuleContainer implements DebugOptionsListener {
 						// skip modules who should have already been started
 						continue;
 					} else if (moduleStartLevel == toStartLevel) {
-						boolean isLazyStart = module.isLazyActivate();
-						if (lazyOnly ? isLazyStart : !isLazyStart) {
-							if (debugStartLevel) {
-								Debug.println("StartLevel: resuming bundle; " + toString(module) + "; with startLevel=" + moduleStartLevel); //$NON-NLS-1$ //$NON-NLS-2$
-							}
-							try {
-								module.start(StartOptions.TRANSIENT_IF_AUTO_START, StartOptions.TRANSIENT_RESUME);
-							} catch (BundleException e) {
-								adaptor.publishContainerEvent(ContainerEvent.ERROR, module, e);
-							} catch (IllegalStateException e) {
-								// been uninstalled
-								continue;
-							}
-						}
+						toStart.add(module);
 					} else {
-						// can stop resuming since any remaining modules have a greater startlevel than the active startlevel
 						break;
 					}
 				} catch (IllegalStateException e) {
@@ -1699,6 +1824,41 @@ public final class ModuleContainer implements DebugOptionsListener {
 					continue;
 				}
 			}
+			if (toStart.isEmpty()) {
+				return;
+			}
+			final Executor executor = inParallel ? adaptor.getStartLevelExecutor() : new Executor() {
+				@Override
+				public void execute(Runnable command) {
+					command.run();
+				}
+			};
+			final CountDownLatch done = new CountDownLatch(toStart.size());
+			for (final Module module : toStart) {
+				executor.execute(new Runnable() {
+					@Override
+					public void run() {
+						try {
+							if (debugStartLevel) {
+								Debug.println("StartLevel: resuming bundle; " + ContainerStartLevel.this.toString(module) + "; with startLevel=" + toStartLevel); //$NON-NLS-1$ //$NON-NLS-2$
+							}
+							module.start(StartOptions.TRANSIENT_IF_AUTO_START, StartOptions.TRANSIENT_RESUME);
+						} catch (BundleException e) {
+							adaptor.publishContainerEvent(ContainerEvent.ERROR, module, e);
+						} catch (IllegalStateException e) {
+							// been uninstalled
+						} finally {
+							done.countDown();
+						}
+					}
+				});
+
+			}
+			try {
+				done.await();
+			} catch (InterruptedException e) {
+				adaptor.publishContainerEvent(ContainerEvent.ERROR, moduleDatabase.getModule(0), e);
+			}
 		}
 
 		private void decStartLevel(int toStartLevel, List<Module> sortedModules) {
@@ -1766,7 +1926,7 @@ public final class ModuleContainer implements DebugOptionsListener {
 			}
 		}
 
-		private String toString(Module m) {
+		String toString(Module m) {
 			Bundle b = m.getBundle();
 			return b != null ? b.toString() : m.toString();
 		}
