@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2017 IBM Corporation and others.
+ * Copyright (c) 2012, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -222,7 +222,7 @@ public class EquinoxBundle implements Bundle, BundleReference {
 									SystemBundle.this.getEquinoxContainer().getLogServices().log(EquinoxContainer.NAME, FrameworkLogEntry.ERROR, "Error stopping the framework.", e); //$NON-NLS-1$
 								}
 							}
-						}, "Framework stop"); //$NON-NLS-1$
+						}, "Framework stop - " + getEquinoxContainer().toString()); //$NON-NLS-1$
 						t.start();
 					}
 				} finally {
@@ -246,7 +246,7 @@ public class EquinoxBundle implements Bundle, BundleReference {
 									SystemBundle.this.getEquinoxContainer().getLogServices().log(EquinoxContainer.NAME, FrameworkLogEntry.ERROR, "Error updating the framework.", e); //$NON-NLS-1$
 								}
 							}
-						}, "Framework update"); //$NON-NLS-1$
+						}, "Framework update - " + getEquinoxContainer().toString()); //$NON-NLS-1$
 						t.start();
 					}
 				} finally {
@@ -287,14 +287,14 @@ public class EquinoxBundle implements Bundle, BundleReference {
 		}
 
 		void addInitFrameworkListeners() {
-			BundleContext context = createBundleContext(false);
+			BundleContext context = createBundleContext();
 			for (FrameworkListener initListener : initListeners) {
 				context.addFrameworkListener(initListener);
 			}
 		}
 
 		void removeInitListeners() {
-			BundleContext context = createBundleContext(false);
+			BundleContext context = createBundleContext();
 			for (FrameworkListener initListener : initListeners) {
 				context.removeFrameworkListener(initListener);
 			}
@@ -480,13 +480,9 @@ public class EquinoxBundle implements Bundle, BundleReference {
 
 	@Override
 	public void update(InputStream input) throws BundleException {
-		try {
-			Storage storage = equinoxContainer.getStorage();
-			storage.update(module, storage.getContentConnection(module, null, input));
-			signerInfos = null;
-		} catch (IOException e) {
-			throw new BundleException("Error reading bundle content.", e); //$NON-NLS-1$
-		}
+		Storage storage = equinoxContainer.getStorage();
+		storage.update(module, input);
+		signerInfos = null;
 	}
 
 	@Override
@@ -721,10 +717,10 @@ public class EquinoxBundle implements Bundle, BundleReference {
 	@Override
 	public BundleContext getBundleContext() {
 		equinoxContainer.checkAdminPermission(this, AdminPermission.CONTEXT);
-		return createBundleContext(true);
+		return createBundleContext();
 	}
 
-	BundleContextImpl createBundleContext(boolean checkPermission) {
+	BundleContextImpl createBundleContext() {
 		if (isFragment()) {
 			// fragments cannot have contexts
 			return null;
@@ -971,7 +967,7 @@ public class EquinoxBundle implements Bundle, BundleReference {
 	}
 
 	/**
-	 * Check for permission to get a service.
+	 * Check for permission to adapt.
 	 */
 	private <A> void checkAdaptPermission(Class<A> adapterType) {
 		SecurityManager sm = System.getSecurityManager();
@@ -999,7 +995,7 @@ public class EquinoxBundle implements Bundle, BundleReference {
 
 	private final void checkValid() {
 		if (module.getState().equals(State.UNINSTALLED))
-			throw new IllegalStateException("Module has been uninstalled."); //$NON-NLS-1$
+			throw new IllegalStateException("Bundle has been uninstalled: " + this); //$NON-NLS-1$
 	}
 
 	public boolean isFragment() {
@@ -1007,9 +1003,9 @@ public class EquinoxBundle implements Bundle, BundleReference {
 	}
 
 	void startWorker0() throws BundleException {
-		BundleContextImpl current = createBundleContext(false);
+		BundleContextImpl current = createBundleContext();
 		if (current == null) {
-			throw new BundleException("Unable to create bundle context!"); //$NON-NLS-1$
+			throw new BundleException("Unable to create bundle context! " + this); //$NON-NLS-1$
 		}
 		try {
 			current.start();
