@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2019 IBM Corporation and others.
+ * Copyright (c) 2003, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -160,7 +160,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 	public static final String ECLIPSE_FRAMEWORK_VENDOR = "Eclipse"; //$NON-NLS-1$
 
 	public static final String PROP_OSGI_JAVA_PROFILE = "osgi.java.profile"; //$NON-NLS-1$
-	public static final String PROP_OSGI_JAVA_PROFILE_NAME = "osgi.java.profile.name"; //$NON-NLS-1$ 
+	public static final String PROP_OSGI_JAVA_PROFILE_NAME = "osgi.java.profile.name"; //$NON-NLS-1$
 	// OSGi java profile bootdelegation; used to indicate how the org.osgi.framework.bootdelegation
 	// property defined in the java profile should be processed, (ingnore, override, none). default is ignore
 	public static final String PROP_OSGI_JAVA_PROFILE_BOOTDELEGATION = "osgi.java.profile.bootdelegation"; //$NON-NLS-1$
@@ -186,7 +186,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 
 	public static final String PROP_ROOT_LOCALE = "equinox.root.locale"; //$NON-NLS-1$
 
-	public static final String PROP_PARENT_CLASSLOADER = "osgi.parentClassloader"; //$NON-NLS-1$	
+	public static final String PROP_PARENT_CLASSLOADER = "osgi.parentClassloader"; //$NON-NLS-1$
 	// A parent classloader type that specifies the framework classlaoder
 	public static final String PARENT_CLASSLOADER_FWK = "fwk"; //$NON-NLS-1$
 	// System property used to set the context classloader parent classloader type (ccl is the default)
@@ -223,6 +223,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 	public static final String PROP_MODULE_AUTO_START_ON_RESOLVE = "osgi.module.auto.start.on.resolve"; //$NON-NLS-1$
 	public static final String PROP_ALLOW_RESTRICTED_PROVIDES = "osgi.equinox.allow.restricted.provides"; //$NON-NLS-1$
 	public static final String PROP_LOG_HISTORY_MAX = "equinox.log.history.max"; //$NON-NLS-1$
+	public static final String PROP_LOG_CAPTURE_ENTRY_LOCATION = "equinox.log.capture.entry.location"; //$NON-NLS-1$
 
 	@Deprecated
 	public static final String PROP_RESOLVER_THREAD_COUNT = "equinox.resolver.thead.count"; //$NON-NLS-1$
@@ -265,7 +266,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 
 		public ConfigValues(Map<String, ?> initialConfiguration, Map<Throwable, Integer> exceptions) {
 			this.exceptions = exceptions;
-			this.initialConfig = initialConfiguration == null ? new HashMap<String, Object>(0) : new HashMap<>(initialConfiguration);
+			this.initialConfig = initialConfiguration == null ? new HashMap<>(0) : new HashMap<>(initialConfiguration);
 			Object useSystemPropsValue = initialConfig.get(PROP_USE_SYSTEM_PROPERTIES);
 			this.useSystemProperties = useSystemPropsValue == null ? false : Boolean.parseBoolean(useSystemPropsValue.toString());
 			Properties tempConfiguration = useSystemProperties ? EquinoxContainer.secureAction.getProperties() : new Properties();
@@ -414,7 +415,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 								Method getenv = System.class.getMethod("getenv", new Class[] {String.class}); //$NON-NLS-1$
 								prop = (String) getenv.invoke(null, new Object[] {var});
 							} catch (Throwable t) {
-								// do nothing; 
+								// do nothing;
 								// on 1.4 VMs this throws an error
 								// on J2ME this method does not exist
 							}
@@ -956,8 +957,15 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 				setConfiguration(PROP_FRAMEWORK, externalForm);
 			}
 			if (getConfiguration(EquinoxLocations.PROP_INSTALL_AREA) == null) {
-				String filePart = getFrameworkPath(url.getPath(), true);
-				setConfiguration(EquinoxLocations.PROP_INSTALL_AREA, filePart);
+				String installArea;
+				if ("file".equals(url.getProtocol())) { //$NON-NLS-1$
+					installArea = getFrameworkPath(url.getPath(), true);
+				} else {
+					// likely not a full eclipse install, and probably not loaded out of a typical
+					// URL class loader. Just default to the user dir.
+					installArea = System.getProperty("user.dir"); //$NON-NLS-1$
+				}
+				setConfiguration(EquinoxLocations.PROP_INSTALL_AREA, installArea);
 			}
 		}
 		// always decode these properties
@@ -1035,7 +1043,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 		/*
 		 * Initializes the execution context for this run of the platform.  The context
 		 * includes information about the locale, operating system and window system.
-		 * 
+		 *
 		 * NOTE: The OS, WS, and ARCH values should never be null. The executable should
 		 * be setting these values and therefore this code path is obsolete for Eclipse
 		 * when run from the executable.
@@ -1052,7 +1060,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 		nlValue = Locale.getDefault().toString();
 		setConfiguration(PROP_OSGI_NL, nlValue);
 
-		// if the user didn't set the operating system with a command line 
+		// if the user didn't set the operating system with a command line
 		// argument then use the default.
 		String osValue = getConfiguration(PROP_OSGI_OS);
 		if (osValue == null) {
@@ -1060,7 +1068,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 			setConfiguration(PROP_OSGI_OS, osValue);
 		}
 
-		// if the user didn't set the window system with a command line 
+		// if the user didn't set the window system with a command line
 		// argument then use the default.
 		String wsValue = getConfiguration(PROP_OSGI_WS);
 		if (wsValue == null) {
@@ -1068,7 +1076,7 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 			setConfiguration(PROP_OSGI_WS, wsValue);
 		}
 
-		// if the user didn't set the system architecture with a command line 
+		// if the user didn't set the system architecture with a command line
 		// argument then use the default.
 		String archValue = getConfiguration(PROP_OSGI_ARCH);
 		if (archValue == null) {
@@ -1137,22 +1145,22 @@ public class EquinoxConfiguration implements EnvironmentInfo {
 	 * <p>
 	 * Converts a String to a Locale.
 	 * </p>
-	 * 
+	 *
 	 * <p>
 	 * This method takes the string format of a locale and creates the locale object from it.
 	 * </p>
-	 * 
+	 *
 	 * <p>
 	 * This method validates the input strictly. The language code must be lowercase. The country
 	 * code must be uppercase. The separator must be an underscore. The length must be correct.
 	 * </p>
-	 * 
+	 *
 	 * <p>
 	 * This method is inspired by <code>org.apache.commons.lang.LocaleUtils.toLocale(String)</code>
 	 * by fixing the parsing error for uncommon Locales like having a language and a variant code
 	 * but no country code, or a Locale that only consists of a country code.
 	 * </p>
-	 * 
+	 *
 	 * @param str
 	 *            the locale String to convert
 	 * @param defaultLocale
