@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -15,11 +15,18 @@
 package org.eclipse.osgi.internal.serviceregistry;
 
 import java.util.Dictionary;
-import org.osgi.framework.*;
+import org.eclipse.osgi.internal.framework.DTOBuilder;
+import org.osgi.framework.AdaptPermission;
+import org.osgi.framework.Bundle;
+import org.osgi.framework.BundleContext;
+import org.osgi.framework.Constants;
+import org.osgi.framework.ServiceReference;
+import org.osgi.framework.ServiceRegistration;
+import org.osgi.framework.dto.ServiceReferenceDTO;
 
 /**
  * A reference to a service.
- * 
+ *
  * <p>
  * The Framework returns <code>ServiceReference</code> objects from the
  * <code>BundleContext.getServiceReference</code> and
@@ -40,7 +47,7 @@ import org.osgi.framework.*;
  * If the same service object is registered multiple times,
  * <code>ServiceReference</code> objects associated with different
  * <code>ServiceRegistration</code> objects are not equal.
- * 
+ *
  * @see BundleContext#getServiceReference
  * @see BundleContext#getServiceReferences
  * @see BundleContext#getService
@@ -66,16 +73,16 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * Returns the property value to which the specified property key is mapped
 	 * in the properties <code>Dictionary</code> object of the service
 	 * referenced by this <code>ServiceReference</code> object.
-	 * 
+	 *
 	 * <p>
 	 * Property keys are case-insensitive.
-	 * 
+	 *
 	 * <p>
 	 * This method must continue to return property values after the service has
 	 * been unregistered. This is so references to unregistered services (for
 	 * example, <code>ServiceReference</code> objects stored in the log) can
 	 * still be interrogated.
-	 * 
+	 *
 	 * @param key The property key.
 	 * @return The property value to which the key is mapped; <code>null</code>
 	 *         if there is no property named after the key.
@@ -89,20 +96,20 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * Returns an array of the keys in the properties <code>Dictionary</code>
 	 * object of the service referenced by this <code>ServiceReference</code>
 	 * object.
-	 * 
+	 *
 	 * <p>
 	 * This method will continue to return the keys after the service has been
 	 * unregistered. This is so references to unregistered services (for
 	 * example, <code>ServiceReference</code> objects stored in the log) can
 	 * still be interrogated.
-	 * 
+	 *
 	 * <p>
 	 * This method is <i>case-preserving </i>; this means that every key in the
 	 * returned array must have the same case as the corresponding key in the
 	 * properties <code>Dictionary</code> that was passed to the
 	 * {@link BundleContext#registerService(String[],Object,java.util.Dictionary)}
 	 * or {@link ServiceRegistration#setProperties} methods.
-	 * 
+	 *
 	 * @return An array of property keys.
 	 */
 	@Override
@@ -113,12 +120,12 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	/**
 	 * Returns the bundle that registered the service referenced by this
 	 * <code>ServiceReference</code> object.
-	 * 
+	 *
 	 * <p>
 	 * This method must return <code>null</code> when the service has been
 	 * unregistered. This can be used to determine if the service has been
 	 * unregistered.
-	 * 
+	 *
 	 * @return The bundle that registered the service referenced by this
 	 *         <code>ServiceReference</code> object; <code>null</code> if
 	 *         that service has already been unregistered.
@@ -133,12 +140,12 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * Returns the bundles that are using the service referenced by this
 	 * <code>ServiceReference</code> object. Specifically, this method returns
 	 * the bundles whose usage count for that service is greater than zero.
-	 * 
+	 *
 	 * @return An array of bundles whose usage count for the service referenced
 	 *         by this <code>ServiceReference</code> object is greater than
 	 *         zero; <code>null</code> if no bundles are currently using that
 	 *         service.
-	 * 
+	 *
 	 * @since 1.1
 	 */
 	@Override
@@ -163,25 +170,25 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * package source of the specified bundle then return <code>true</code>;
 	 * otherwise return <code>false</code>.</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param bundle The <code>Bundle</code> object to check.
 	 * @param className The class name to check.
 	 * @return <code>true</code> if the bundle which registered the service
 	 *         referenced by this <code>ServiceReference</code> and the
 	 *         specified bundle use the same source for the package of the
 	 *         specified class name. Otherwise <code>false</code> is returned.
-	 * 
+	 *
 	 * @since 1.3
 	 */
 	@Override
 	public boolean isAssignableTo(Bundle bundle, String className) {
-		return registration.isAssignableTo(bundle, className);
+		return registration.isAssignableTo(bundle, className, true);
 	}
 
 	/**
 	 * Compares this <code>ServiceReference</code> with the specified
 	 * <code>ServiceReference</code> for order.
-	 * 
+	 *
 	 * <p>
 	 * If this <code>ServiceReference</code> and the specified
 	 * <code>ServiceReference</code> have the same
@@ -196,7 +203,7 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * <code>ServiceReference</code> if it has a higher
 	 * {@link Constants#SERVICE_ID service id} and greater if it has a lower
 	 * service id.
-	 * 
+	 *
 	 * @param object The <code>ServiceReference</code> to be compared.
 	 * @return Returns a negative integer, zero, or a positive integer if this
 	 *         <code>ServiceReference</code> is less than, equal to, or
@@ -270,7 +277,7 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 
 	/**
 	 * Return the ServiceRegistrationImpl for this ServiceReferenceImpl.
-	 * 
+	 *
 	 * @return The ServiceRegistrationImpl for this ServiceReferenceImpl.
 	 */
 	public ServiceRegistrationImpl<S> getRegistration() {
@@ -309,7 +316,7 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	 * {@link ServiceRegistration#setProperties(Dictionary)} must be called to
 	 * modify the properties of the service.</li>
 	 * </ul>
-	 * 
+	 *
 	 * @return A copy of the properties of the service referenced by this
 	 *         {@code ServiceReference} object
 	 * @since 1.9
@@ -318,4 +325,22 @@ public class ServiceReferenceImpl<S> implements ServiceReference<S> {
 	public Dictionary<String, Object> getProperties() {
 		return registration.getPropertiesCopy();
 	}
+
+	@SuppressWarnings("unchecked")
+	@Override
+	public <A> A adapt(Class<A> type) {
+		checkAdaptPermission(type);
+		if (ServiceReferenceDTO.class.equals(type)) {
+			return (A) DTOBuilder.newServiceReferenceDTO(this);
+		}
+		return null;
+	}
+
+	private <A> void checkAdaptPermission(Class<A> adapterType) {
+		SecurityManager sm = System.getSecurityManager();
+		if (sm == null) {
+			return;
+		}
+		sm.checkPermission(new AdaptPermission(adapterType.getName(), registration.getRegisteringBundle(), AdaptPermission.ADAPT));
+	}
 }
